# Topsis-Sanchita-102003177

## Installation
```pip install topsis-sanchita-102003177```

## How to use it?
Open terminal and type topsis-sanchita-102003177 and then input
```topsis-sanchita-102003177 <script_name> <input_data_file_name> <wt> <imp> <result_file_name>```

## License
This repository is licensed under the MIT license. 
